@@ -1,5 +1,5 @@
 # Metadata
-__version__ = "0.3.1"
+__version__ = "0.4.0"
 
 # Authentication scheme.
 from disruptive.authentication import Auth  # noqa
@@ -29,8 +29,9 @@ from disruptive.resources.emulator import Emulator  # noqa
 # Additional helper modules.
 import disruptive.events as events  # noqa
 
-# If True, debug information is sent to stdout.
-log = False
+# If set, logs of chosen level and higher are printed to console.
+# Available levels are: debug, info, warning, error, critical.
+log_level = None
 
 # REST API base URLs of which all endpoints are an expansion.
 api_url = 'https://api.disruptive-technologies.com/v2'
@@ -41,4 +42,4 @@ auth_url = 'https://identity.disruptive-technologies.com/oauth2/token'
 # worth considering, these variable determine how long to wait without an
 # answer, and how many times the package should retry before raising an error.
 request_timeout = 3  # seconds
-request_retries = 3  # attempts
+request_attempts = 5  # attempts
