@@ -1,14 +1,11 @@
 from __future__ import annotations
 
-# Standard library imports.
 import time
 import json
 from typing import Optional
 
-# Third-party imports.
 import requests
 
-# Project imports
 import disruptive as dt
 import disruptive.logging as dtlog
 import disruptive.errors as dterrors
@@ -28,8 +25,7 @@ class DTRequest():
         self.body = None
         self.data = None
         self.request_timeout = dt.request_timeout
-        self.request_retries = dt.request_retries
-        self.log = dt.log
+        self.request_attempts = dt.request_attempts
 
         # Unpack kwargs and set attributes thereafter.
         self._unpack_kwargs(**kwargs)
@@ -54,18 +50,14 @@ class DTRequest():
         if 'request_timeout' in kwargs:
             self.request_timeout = kwargs['request_timeout']
 
-        # Check if request_retries is overriden.
-        if 'request_retries' in kwargs:
-            self.request_retries = kwargs['request_retries']
+        # Check if request_attempts is overriden.
+        if 'request_attempts' in kwargs:
+            self.request_attempts = kwargs['request_attempts']
 
         # Check if base_url is overriden.
         if 'base_url' in kwargs:
             self.base_url = kwargs['base_url']
 
-        # Check if log is overriden.
-        if 'log' in kwargs:
-            self.log = kwargs['log']
-
         # Add authorization header to request except when explicitly otherwise.
         if 'skip_auth' not in kwargs or kwargs['skip_auth'] is False:
             # If provided, override the package-wide auth with provided object.
@@ -83,11 +75,11 @@ class DTRequest():
                 'must be float greater than 0.'.format(self.request_timeout)
             )
 
-        # Check that request_retries > 0.
-        if self.request_retries <= 0:
+        # Check that request_attempts > 0.
+        if self.request_attempts <= 0:
             raise dterrors.ConfigurationError(
-                'Configuration parameter request_retries has value {}, but '
-                'must be integer greater than 0.'.format(self.request_retries)
+                'Configuration parameter request_attempts has value {}, but '
+                'must be integer greater than 0.'.format(self.request_attempts)
             )
 
     def _request_wrapper(self,
@@ -124,10 +116,10 @@ class DTRequest():
 
     def _send_request(self, nth_attempt=1):
         # Log the request.
-        dtlog.log('Request [{}] to {}.'.format(
+        dtlog.debug('Request [{}] to {}.'.format(
             self.method,
             self.base_url + self.url
-        ), override=self.log)
+        ))
 
         res, req_error = self._request_wrapper(
             method=self.method,
@@ -140,9 +132,9 @@ class DTRequest():
         )
 
         # Log the response.
-        dtlog.log('Response [{}].'.format(
+        dtlog.debug('Response [{}].'.format(
             res.status_code
-        ), override=self.log)
+        ))
 
         # If _request_wrapper raised an exception, the request failed.
         if req_error is not None:
@@ -158,19 +150,19 @@ class DTRequest():
             )
 
         # Check if retry is required.
-        if should_retry and nth_attempt <= self.request_retries:
-
-            dtlog.log('Error: {}'.format(error))
-            dtlog.log('Attempting reconnect {}/{} in {}s.'.format(
-                nth_attempt,
-                self.request_retries,
-                sleeptime,
-            ), override=self.log)
+        if should_retry and nth_attempt < self.request_attempts:
+            dtlog.error(error)
+            dtlog.warning('Reconnecting in {}s.'.format(sleeptime))
 
             # Sleep if necessary.
             if sleeptime is not None:
                 time.sleep(sleeptime)
 
+            dtlog.info('Connection attempt {}/{}.'.format(
+                nth_attempt+1,
+                self.request_attempts,
+            ))
+
             # Attempt the request again recursively, iterating counter.
             res.data = self._send_request(nth_attempt+1)
 
@@ -238,10 +230,10 @@ class DTRequest():
         # Unpack kwargs.
         params = kwargs['params'] if 'params' in kwargs else {}
         headers = kwargs['headers'] if 'headers' in kwargs else {}
-        if 'request_retries' in kwargs:
-            request_retries = kwargs['request_retries']
+        if 'request_attempts' in kwargs:
+            request_attempts = kwargs['request_attempts']
         else:
-            request_retries = dt.request_retries
+            request_attempts = dt.request_attempts
 
         # Add ping parameter to dictionary.
         params['ping_interval'] = str(PING_INTERVAL) + 's'
@@ -259,7 +251,7 @@ class DTRequest():
                 # Set up a stream connection.
                 # Connection will timeout and reconnect if no single event
                 # is received in an interval of ping_interval + ping_jitter.
-                dtlog.log('Starting stream...')
+                dtlog.info('Starting stream...')
                 stream = requests.request(
                     method='GET',
                     url=url,
@@ -284,7 +276,7 @@ class DTRequest():
                     # Check for ping event.
                     event = payload['result']['event']
                     if event['eventType'] == 'ping':
-                        dtlog.log('Ping received.')
+                        dtlog.debug('Ping received.')
                         continue
 
                     # Yield event to generator.
@@ -300,18 +292,20 @@ class DTRequest():
                 error, should_retry, sleeptime = dterrors.parse_request_error(
                     e, {}, nth_attempt)
 
-                # Print the error and try again up to max_request_retries.
-                if nth_attempt <= request_retries and should_retry:
-                    dtlog.log('Error: {}'.format(error))
-                    dtlog.log('Attempting reconnect {}/{} in {}s.'.format(
-                        nth_attempt,
-                        request_retries,
-                        nth_attempt**2,
-                    ))
+                # Print the error and try again up to max_request_attempts.
+                if nth_attempt < request_attempts and should_retry:
+                    dtlog.error(error)
+                    dtlog.warning('Reconnecting in {}s.'.format(sleeptime))
 
                     # Exponential backoff in sleep time.
                     time.sleep(sleeptime)
+
+                    # Iterate attempt counter.
                     nth_attempt += 1
+                    dtlog.info('Connection attempt {}/{}.'.format(
+                        nth_attempt,
+                        request_attempts,
+                    ))
 
                 else:
                     raise error
