@@ -1,9 +1,7 @@
 from __future__ import annotations
 
-# Standard library imports.
 from typing import Optional
 
-# Project imports.
 import disruptive.logging as dtlog
 import disruptive.requests as dtrequests
 import disruptive.events.events as dtevents
@@ -91,7 +89,7 @@ class Device(dtoutputs.OutputBase):
     @classmethod
     def get_device(cls,
                    device_id: str,
-                   project_id: Optional[str] = None,
+                   project_id: str = '-',
                    **kwargs,
                    ) -> Device:
         """
@@ -110,8 +108,8 @@ class Device(dtoutputs.OutputBase):
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Returns
         -------
@@ -125,9 +123,6 @@ class Device(dtoutputs.OutputBase):
 
         """
 
-        if project_id is None:
-            project_id = '-'
-
         # Construct URL
         url = '/projects/{}/devices/{}'.format(project_id, device_id)
 
@@ -171,8 +166,8 @@ class Device(dtoutputs.OutputBase):
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Returns
         -------
@@ -240,8 +235,8 @@ class Device(dtoutputs.OutputBase):
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Examples
         --------
@@ -302,8 +297,8 @@ class Device(dtoutputs.OutputBase):
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Examples
         --------
@@ -350,8 +345,8 @@ class Device(dtoutputs.OutputBase):
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Examples
         --------
@@ -405,8 +400,8 @@ class Device(dtoutputs.OutputBase):
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Raises
         ------
@@ -552,4 +547,4 @@ class Reported(dtoutputs.OutputBase):
                     data,
                 )
             else:
-                dtlog.log('Skipping unknown event type {}.'.format(key))
+                dtlog.warning('Skipping unknown event type {}.'.format(key))
