@@ -42,8 +42,8 @@ class Emulator():
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Returns
         -------
@@ -104,8 +104,8 @@ class Emulator():
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Examples
         --------
@@ -160,8 +160,8 @@ class Emulator():
             If provided it will be prioritized over global authentication.
         request_timeout: int, optional
             Seconds before giving up a request without an answer.
-        request_retries: int, optional
-            Maximum number of times to retry a request before giving up.
+        request_attempts: int, optional
+            Number of times a request is attempted before giving up.
 
         Examples
         --------
